@@ -96,9 +96,10 @@ class LeCrapaud:
         self, name: str, metric: str = "both", **kwargs
     ) -> "ExperimentEngine":
         """Retrieve the best experiment by score."""
-        return ExperimentEngine(
-            id=Experiment.get_best_by_score(name=name, metric=metric).id, **kwargs
-        )
+        best_exp = Experiment.get_best_by_score(name=name, metric=metric)
+        if not best_exp:
+            return None
+        return ExperimentEngine(id=best_exp.id, **kwargs)
 
     def compare_experiment_scores(self, name: str):
         """Compare scores of experiments with matching names.
