@@ -6,6 +6,7 @@ from sqlalchemy import pool
 from alembic import context
 from lecrapaud.db.session import DATABASE_URL
 from lecrapaud.db.models.base import Base
+from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
 
 # this is the Alembic Config object, which provides
 # access to the values within the .ini file in use.
@@ -15,7 +16,7 @@ config.set_main_option("sqlalchemy.url", DATABASE_URL)
 # Interpret the config file for Python logging.
 # This line sets up loggers basically.
 if config.config_file_name is not None:
-    fileConfig(config.config_file_name)
+    fileConfig(config.config_file_name, disable_existing_loggers=False)
 
 # add your model's MetaData object here
 # for 'autogenerate' support
@@ -46,7 +47,7 @@ def run_migrations_offline() -> None:
         target_metadata=target_metadata,
         literal_binds=True,
         dialect_opts={"paramstyle": "named"},
-        version_table="lecrapaud_alembic_version",
+        version_table=f"{LECRAPAUD_TABLE_PREFIX}_alembic_version",
     )
 
     with context.begin_transaction():
@@ -70,7 +71,7 @@ def run_migrations_online() -> None:
         context.configure(
             connection=connection,
             target_metadata=target_metadata,
-            version_table="lecrapaud_alembic_version",
+            version_table=f"{LECRAPAUD_TABLE_PREFIX}_alembic_version",
         )
 
         with context.begin_transaction():
