@@ -1,6 +1,5 @@
 from lecrapaud.db.models.base import Base
-
-from lecrapaud.db.models.dataset import Dataset
+from lecrapaud.db.models.experiment import Experiment
 from lecrapaud.db.models.feature_selection_rank import FeatureSelectionRank
 from lecrapaud.db.models.feature_selection import FeatureSelection
 from lecrapaud.db.models.feature import Feature
@@ -9,3 +8,16 @@ from lecrapaud.db.models.model_training import ModelTraining
 from lecrapaud.db.models.model import Model
 from lecrapaud.db.models.score import Score
 from lecrapaud.db.models.target import Target
+
+__all__ = [
+    'Base',
+    'Experiment',
+    'FeatureSelectionRank',
+    'FeatureSelection',
+    'Feature',
+    'ModelSelection',
+    'ModelTraining',
+    'Model',
+    'Score',
+    'Target',
+]
