@@ -25,7 +25,7 @@ from lecrapaud.db.models.score import Score
 
 from lecrapaud.db.models.base import Base, with_db
 from lecrapaud.db.models.utils import create_association_table
-from lecrapaud.utils import logger
+from lecrapaud.utils import logger, contains_best
 
 # jointures
 lecrapaud_experiment_target_association = create_association_table(
@@ -237,13 +237,27 @@ class Experiment(Base):
         Returns:
             Experiment or None: The experiment with the best score or None if not found
         """
+        experiments = db.query(cls).filter(cls.name.ilike(f"%{name}%")).all()
+        if not experiments:
+            logger.error(f"No experiments found with the given name: {name}")
+            return None
+
+        experiments = [
+            exp
+            for exp in experiments
+            if all(
+                [contains_best(f"{exp.path}/{target.name}") for target in exp.targets]
+            )
+        ]
+        if not experiments:
+            logger.error(
+                f"No fully trained experiments found with the given name: {name}"
+            )
+            return None
+
         if metric == "both":
             # Calculate a combined score: average of normalized RMSE and LogLoss
             # This ensures we're comparing apples to apples by normalizing the scores
-            experiments = db.query(cls).filter(cls.name.ilike(f"%{name}%")).all()
-            if not experiments:
-                logger.error(f"No experiments found with the given name: {name}")
-                return None
 
             # Get all scores
             rmse_scores = [e.avg_rmse for e in experiments if e.avg_rmse is not None]
@@ -284,11 +298,6 @@ class Experiment(Base):
 
         elif metric == "rmse" or metric == "logloss":
             # For single metric case (rmse or logloss)
-            # Need to get all experiments first to evaluate instance properties
-            experiments = db.query(cls).filter(cls.name.ilike(f"%{name}%")).all()
-
-            if not experiments:
-                return None
 
             # Filter out experiments without scores and sort by the selected metric
             filtered_experiments = []
