@@ -220,7 +220,7 @@ class FeatureEngineeringEngine:
         Returns:
             pd.DataFrame: Original dataframe with new encoded columns added
         """
-
+        # TODO: target encoding needs to be fit / transform based at inference time.
         df: pd.DataFrame = self.data
         columns_te_groupby: list[list[str]] = self.columns_te_groupby
         columns_te_target: list[str] = self.columns_te_target
@@ -231,6 +231,9 @@ class FeatureEngineeringEngine:
         for group_cols, stat, target_col in product(
             columns_te_groupby, statistics, columns_te_target
         ):
+            df[target_col] = pd.to_numeric(
+                df[target_col].replace("", "0"), errors="coerce"
+            ).fillna(0)
             col_name = f"{target_col}_{'_'.join(group_cols)}_{stat.upper()}"
             new_feature_cols[col_name] = df.groupby(group_cols)[target_col].transform(
                 stat
