@@ -12,6 +12,7 @@ import glob
 from pathlib import Path
 import pickle
 from pydantic import BaseModel
+import ast
 
 os.environ["COVERAGE_FILE"] = str(Path(".coverage").resolve())
 
@@ -122,6 +123,7 @@ class ModelEngine:
         plot: bool = False,
         log_dir: str = None,
     ):
+        self.threshold = None
         self.path = path
         if path:
             self.load()
@@ -152,8 +154,6 @@ class ModelEngine:
         else:
             self.scaler_y = None
 
-        self.threshold = None
-
     def fit(self, *args):
         if self.recurrent:
             fit = self.fit_recurrent
@@ -1070,7 +1070,7 @@ class ModelSelectionEngine:
         best_score_overall = scores_tracking.iloc[0, :]
         best_model_name = best_score_overall["MODEL_NAME"]
         if self.target_type == "classification":
-            best_thresholds = best_score_overall["THRESHOLDS"]
+            best_thresholds = ast.literal_eval(best_score_overall["THRESHOLDS"])
             joblib.dump(best_thresholds, f"{self.target_dir}/thresholds.pkl")
         else:
             best_thresholds = None
@@ -1852,7 +1852,9 @@ def apply_thresholds(
     """
 
     # Case 1: Per-class thresholds
-    if isinstance(threshold, dict):
+    if not isinstance(threshold, (int, float)):
+        if isinstance(threshold, str):
+            threshold = ast.literal_eval(threshold)
         class_predictions = []
         class_probabilities = []
 
@@ -1862,6 +1864,7 @@ def apply_thresholds(
                 metrics.get("threshold") if isinstance(metrics, dict) else metrics[0]
             )
             if _threshold is not None:
+                class_label = int(class_label)
                 if class_label not in pred_proba.columns:
                     continue  # skip missing class
                 col = pred_proba[class_label]
