@@ -835,14 +835,33 @@ dl_recurrent_models = [
     },
 ]
 
+all_models = ml_models + dl_recurrent_models
+
 
 def get_models_idx(*model_names):
-    models = ml_models + dl_recurrent_models
-
     matching_idx = [
-        i for i, model in enumerate(models) if model["model_name"] in model_names
+        i for i, model in enumerate(all_models) if model["model_name"] in model_names
     ]
     return matching_idx
 
 
-all_models = ml_models + dl_recurrent_models
+def normalize_models_idx(models_idx: list[int | str]) -> list[int]:
+    """
+    Convert a list of model identifiers (int or str) to a list of model indices (int).
+    If an element is a string, it is resolved using `get_models_idx`.
+
+    Returns:
+        List of model indices (ints).
+    """
+    normalized = []
+    for model_idx in models_idx:
+        if isinstance(model_idx, int):
+            normalized.append(model_idx)
+        elif isinstance(model_idx, str):
+            resolved = get_models_idx(model_idx)
+            if not resolved:
+                raise ValueError(f"No model index found for name: {model_idx}")
+            normalized.append(resolved[0])
+        else:
+            raise TypeError(f"Unsupported type: {type(model_idx)}")
+    return normalized
