@@ -9,22 +9,24 @@ from ftfy import fix_text
 import unicodedata
 import re
 import string
-import sys
+
 from lecrapaud.directories import logger_dir
 from lecrapaud.config import LOGGING_LEVEL, PYTHON_ENV, LECRAPAUD_LOCAL
 
+
 _LECRAPAUD_LOGGER_ALREADY_CONFIGURED = False
 
 
 def setup_logger():
 
+    name = "lecrapaud"
+
     global _LECRAPAUD_LOGGER_ALREADY_CONFIGURED
     if _LECRAPAUD_LOGGER_ALREADY_CONFIGURED:  # ← bail out if done before
-
-        return logging.getLogger("lecrapaud" if PYTHON_ENV != "Worker" else "")
+        return logging.getLogger(name if PYTHON_ENV != "Worker" else "")
 
     print(
-        f"Setting up logger lecrapaud with PYTHON_ENV {PYTHON_ENV} and LOGGING_LEVEL {LOGGING_LEVEL}"
+        f"Setting up logger for {name} with PYTHON_ENV {PYTHON_ENV} and LOGGING_LEVEL {LOGGING_LEVEL}"
     )
     # ------------------------------------------------------------------ #
     #  Real configuration happens only on the FIRST call                 #
